package com.cardiff.client_project.mapper;

import com.cardiff.client_project.constant.Authority;
import com.cardiff.client_project.constant.ResponseCode;
import com.cardiff.client_project.pojo.entity.Patient;

import com.cardiff.client_project.utils.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Repository
public class PatientMapper {

    @Autowired
    JdbcTemplate jdbcTemplate;
    /**
     * update patient data
     * @param patient
     * @return
     */
    public int update(Patient patient) {
        String sql = "UPDATE patient SET name = ?,phone = ?, age=?, email=?, status = ?,hospitalId =? WHERE id = ?";
        int update = jdbcTemplate.update(sql, preparedStatement -> {
            preparedStatement.setString(1, patient.getName());
            preparedStatement.setString(2, patient.getPhone());
            preparedStatement.setInt(3, patient.getAge());
            preparedStatement.setString(4, patient.getEmail());
            preparedStatement.setInt(5, patient.getStatus());
            preparedStatement.setInt(6, patient.getHospitalId());
            preparedStatement.setInt(7, patient.getId());
        });
        return update;
    }

    /**
     * select patient
     * @return
     */
    public List<Patient> selectAllPatient(int hospitalId){

        // Parameterized queries avoid SQL injection
        String sql = "SELECT * FROM patient where hospitalId=?";
        List<Patient> query = jdbcTemplate.query(sql, new BeanPropertyRowMapper<>(Patient.class), hospitalId);
        System.out.println(query);
        return query;
    }


    /**
     * fuzzy query
     * @param patient
     * @return
     */
    public List<Patient> selectByItem(Patient patient) {
        System.out.println("test:" + patient);
        // Build the basic SQL and parameter list
        StringBuilder sql = new StringBuilder("SELECT * FROM patient");

        //Dynamic table name stitching
        sql.append(" WHERE 1=1 ");
        List<Object> params = new ArrayList<>();

        //Dynamic concatenation of query conditions
        if (patient.getName() != null && patient.getName() != "") {
            sql.append(" AND name LIKE ?");
            params.add("%" + patient.getName() + "%");
        }
        if (patient.getPhone() != null && patient.getPhone() != "") {
            sql.append(" AND phone LIKE ?");
            params.add("%" + patient.getPhone() + "%");
        }

//        if (patient.getAddress() != null && patient.getAddress() != "") {
//            sql.append(" AND address LIKE ?");
//            params.add("%" + patient.getAddress() + "%");
//        }

        if (Integer.valueOf(patient.getStatus()) != null) {
            sql.append(" AND status = ?, ");
            params.add(patient.getStatus());
        }
        sql.setLength(sql.length() - 2);

        System.out.println("sql: "+sql.toString());
        List<Patient> query = jdbcTemplate.query(sql.toString(), params.toArray(), new BeanPropertyRowMapper<>(Patient.class));
        System.out.println("query" + query);
        return query;

    }

    /**
     * Query data by name
     * @param name
     * @return
     */
    public Object getPatientByName(String name){
        try {
            // 1. 查询 patient 表
            String sql = "select * from patient where name=?";
            return jdbcTemplate.queryForObject(sql, new Object[]{name}, new BeanPropertyRowMapper<>(Patient.class));
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 如果所有查询都为空，返回 null
        return null;
    }

    /**
     * Get role permissions based on id
     * @param roleId
     * @return
     */
    public String getTypeById(int roleId) {
        String sql="SELECT type from role where roleId=?;";
        String type= jdbcTemplate.queryForObject(sql, new Object[]{roleId}, String.class);
        return type;
    }

    /**
     * insert patient
     * @param patient
     */
    public Result insertPatientInform(Patient patient) {
        //Check whether the account exists(If the name and email address are the same, the account is confirmed to exist)
        String sql = "SELECT count(id) FROM patient where name = ? and email = ?";
        Integer count= jdbcTemplate.queryForObject(sql, new Object[]{patient.getName(), patient.getEmail()}, Integer.class);
        System.out.println(count);
        if(count > 0){
            return Result.error(ResponseCode.ACCOUNT_EXISTS_ERROR);
        }

        //insert data
        SimpleJdbcInsert insert = new SimpleJdbcInsert(jdbcTemplate)
                .withTableName("patient")
                .usingGeneratedKeyColumns("id");

        Map<String, Object> parameters = new HashMap<>();
        parameters.put("Id",patient.getId());
        parameters.put("hospitalId",patient.getHospitalId());
        parameters.put("name",patient.getName());
        parameters.put("age", patient.getAge());
        parameters.put("phone",patient.getPhone());
        parameters.put("email",patient.getEmail());
        parameters.put("roleId",patient.getRoleId());
        parameters.put("type",patient.getType());
        //parameters.put("address", patient.getAddress());
        parameters.put("status",patient.getStatus());

        Number number = insert.executeAndReturnKey(parameters);
        if(number.longValue() > 0){
            return Result.success(ResponseCode.SUCCESS);
        }else {
            return Result.error(ResponseCode.ERROR);
        }
    }

    /**
     * Batch deletion based on id
     * @param ids
     * @return
     */
    public int[] deleteByIdAndType(List<Integer> ids, String type) {
        String sql = "DELETE FROM patient WHERE id=?";
        String sql_1="ALTER TABLE patient DROP COLUMN id;";
        String sql_2="ALTER TABLE patient ADD COLUMN id INT NOT NULL PRIMARY KEY AUTO_INCREMENT FIRST;";

        List<Object[]> idList = new ArrayList<>();
        for (Integer id : ids) {
            idList.add(new Object[]{id});
        }
        int[] item = jdbcTemplate.batchUpdate(sql, idList);
        jdbcTemplate.update(sql_1);
        jdbcTemplate.update(sql_2);
        return item;
    }

}

