$(document).ready(function () {
    // Constants
    const API_BASE_URL = '/api/hospitals';
    const DEFAULT_ERROR = 'Operation failed. Please try again.';
    
    // Initialize page
    setupNavBar();
    loadHospitals();
    initializeEventHandlers();

    function setupNavBar() {
        const nav = `
            <nav class="top-nav">
                <div class="nav-brand">Digital Insight for Health</div>
                <div class="nav-items">
                    <a href="/superAdminView.html?type=hospital" class="nav-link">
                        <i class="fas fa-home"></i> Home
                    </a>
                    <a href="/beds.html" class="nav-link active">
                        <i class="fas fa-bed"></i> Beds
                    </a>
                    <button class="nav-link sign-out" onclick="handleSignOut()">
                        <i class="fas fa-sign-out-alt"></i> Sign Out
                    </button>
                </div>
                <div class="user-info">
                    <span class="user-name">${localStorage.getItem('name') || 'User'}</span>
                    <span class="user-role">${localStorage.getItem('type') || 'Guest'}</span>
                </div>
            </nav>
        `;
        $('.main-container').prepend(nav);
    }

    function loadHospitals() {
        showLoading();
        $.ajax({
            url: `${API_BASE_URL}/available`,
            method: 'GET',
            contentType: 'application/json',
            success: function(response) {
                if(response && response.code === 1) {
                    updateTable(response.data || []);
                } else {
                    showError(response.msg || DEFAULT_ERROR);
                }
            },
            error: handleAjaxError
        });
    }

    function updateTable(hospitals) {
        const tbody = $('#hospitalTable tbody');
        tbody.empty();
        
        hospitals.forEach(function(hospital) {
            const tr = `
                <tr>
                    <td>${hospital.id}</td>
                    <td>${hospital.name || ''}</td>
                    <td>${hospital.location || ''}</td>
                    <td>${hospital.phone || ''}</td>
                    <td>${hospital.totalBeds || 0}</td>
                    <td>${hospital.availableBeds || 0}</td>
                    <td>${Math.round(hospital.occupancyRate)}%</td>
                    <td>
                        <button class="btn edit-btn" data-id="${hospital.id}">
                            <i class="fas fa-edit"></i>
                        </button>
                        <button class="btn delete-btn" data-id="${hospital.id}">
                            <i class="fas fa-trash"></i>
                        </button>
                    </td>
                </tr>
            `;
            tbody.append(tr);
        });
    }

    function initializeEventHandlers() {
        // Search Handler
        $("#searchButton").click(handleSearch);

        // Add Hospital Handler
        $("#addHospitalBtn").click(function() {
            $("#hospitalModal").fadeIn();
            $("#modalTitle").text("Add New Hospital");
            $("#hospitalForm")[0].reset();
            $("#hospitalId").val('');
        });

        // Close Modal Handler
        $(".close-btn, #cancelBtn").click(function() {
            $("#hospitalModal").fadeOut();
        });

        // Form Submit Handler
        $("#hospitalForm").submit(function(e) {
            e.preventDefault();
            const formData = {
                name: $("#hospitalName").val(),
                location: $("#hospitalLocation").val(),
                address: $("#hospitalLocation").val(), // Match DB schema
                phone: $("#hospitalPhone").val(),
                totalBeds: parseInt($("#totalBeds").val()),
                availableBeds: parseInt($("#availableBeds").val()),
                type: 'hospital',
                status: 1,
                roleId: 3,
                email: '',
                password: '$2a$10$wvAZoj4V51MH/MLhVIrnG.NrY07/.Gn9Ar6JsyzRAubWtqbWzgKie'
            };

            if (!validateFormData(formData)) {
                showError('Please fill all required fields');
                return;
            }

            $.ajax({
                url: API_BASE_URL,
                method: 'POST',
                contentType: 'application/json',
                data: JSON.stringify(formData),
                success: function(response) {
                    if(response && response.code === 1) {
                        $("#hospitalModal").fadeOut();
                        loadHospitals();
                        showSuccess('Hospital added successfully');
                    } else {
                        showError(response.msg || DEFAULT_ERROR);
                    }
                },
                error: function(xhr, status, error) {
                    console.error('API Error:', error);
                    showError(DEFAULT_ERROR);
                }
            });
        });

        // Delete Handler
        $(document).on('click', '.delete-btn', function() {
            const id = $(this).data('id');
            if(confirm('Are you sure you want to delete this hospital?')) {
                $.ajax({
                    url: `${API_BASE_URL}/${id}`,
                    method: 'DELETE',
                    success: function(response) {
                        if(response && response.code === 1) {
                            loadHospitals();
                            showSuccess('Hospital deleted successfully');
                        } else {
                            showError(response.msg || 'Delete failed');
                        }
                    },
                    error: function(xhr) {
                        console.error('Delete Error:', xhr);
                        showError('Failed to delete hospital');
                    }
                });
            }
        });
    }

    function handleSearch(event) {
        event.preventDefault();
        const searchTerm = $("#searchName").val().trim();
        
        $.ajax({
            url: `${API_BASE_URL}/search`,
            method: 'POST',
            contentType: 'application/json',
            data: JSON.stringify({ name: searchTerm }),
            success: function(response) {
                if(response && response.code === 1) {
                    updateTable(response.data || []);
                } else {
                    showError('No hospitals found');
                }
            },
            error: handleAjaxError
        });
    }

    function handleFormSubmit(event) {
        event.preventDefault();
        const formData = {
            name: $("#hospitalName").val(),
            address: $("#hospitalLocation").val(),
            phone: $("#hospitalPhone").val(),
            maxAmount: parseInt($("#totalBeds").val()),
            amountPatient: parseInt($("#totalBeds").val() - $("#availableBeds").val()),
            type: 'hospital',
            status: 1
        };

        const id = $("#hospitalId").val();
        const method = id ? 'PUT' : 'POST';
        const url = id ? `${API_BASE_URL}/${id}` : API_BASE_URL;

        $.ajax({
            url: url,
            method: method,
            contentType: 'application/json',
            data: JSON.stringify(formData),
            success: function(response) {
                if(response && response.code === 1) {
                    $("#hospitalModal").fadeOut();
                    showSuccess('Operation successful');
                    loadHospitals();
                } else {
                    showError(response.msg || DEFAULT_ERROR);
                }
            },
            error: handleAjaxError
        });
    }

    function handleAjaxError(xhr, status, error) {
        console.error('API Error:', {xhr, status, error});
        showError(DEFAULT_ERROR);
    }

    function showLoading() {
        $('#hospitalTable tbody').html('<tr><td colspan="8" class="text-center">Loading...</td></tr>');
    }

    function showNoDataMessage() {
        $('#hospitalTable tbody').html('<tr><td colspan="8" class="text-center">No hospitals available</td></tr>');
    }

    function showError(message) {
        $('#hospitalTable tbody').html(`<tr><td colspan="8" class="text-center text-danger">${message}</td></tr>`);
    }

    function validateFormData(data) {
        return data.name && 
               data.location && 
               data.phone && 
               data.totalBeds > 0 && 
               data.availableBeds >= 0 && 
               data.availableBeds <= data.totalBeds;
    }

    function showSuccess(message) {
        const alert = `
            <div class="alert alert-success">
                ${message}
            </div>
        `;
        $('.table-container').before(alert);
        setTimeout(() => {
            $('.alert').fadeOut().remove();
        }, 3000);
    }

    // Add CSS for new components
    const styles = `
        .top-nav {
            background: var(--primary-color);
            padding: 1rem 2rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 2rem;
            border-radius: 10px;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }

        .nav-brand {
            color: white;
            font-size: 1.5rem;
            font-weight: 600;
        }

        .nav-items {
            display: flex;
            gap: 1rem;
            align-items: center;
        }

        .nav-link {
            color: white;
            text-decoration: none;
            padding: 0.5rem 1rem;
            border-radius: 6px;
            transition: all 0.3s ease;
        }

        .nav-link:hover, .nav-link.active {
            background: rgba(255,255,255,0.1);
        }

        .sign-out {
            background: var(--danger-color);
            border: none;
            cursor: pointer;
        }

        .user-info {
            display: flex;
            flex-direction: column;
            align-items: flex-end;
            color: white;
        }

        .user-name {
            font-weight: 500;
        }

        .user-role {
            font-size: 0.875rem;
            opacity: 0.8;
        }

        .success-message {
            background: var(--success-color);
            color: white;
            padding: 1rem;
            border-radius: 6px;
            margin-bottom: 1rem;
            display: flex;
            align-items: center;
            justify-content: space-between;
        }
    `;

    $('<style>').text(styles).appendTo('head');

    // Initialize tooltips and other UI enhancements
    $('[data-toggle="tooltip"]').tooltip();
    
    // Add fade effects for smoother transitions
    $('.table-container').hide().fadeIn();
});

function handleSignOut() {
    localStorage.clear();
    window.location.href = '/login.html';
}
